# Zephyr SDK

This is a simple python library that abstracts away the Zephyr SDK. It's still under development, so not all methods are implemented yet. The main body of the documentation for the SDK is found in the [wiki](https://github.com/byu-oit/zephyr-sdk/wiki)